from setuptools import setup

setup(name='imageTest2020',
      version='0.0.5',
      description='string to date',
      author='zxw',
      author_email='761479698@qq.com',
      license='MIT',
      packages=['imageTest2020'])
